from yta_general_utils.programming.enum import YTAEnum as Enum


class ColorString(Enum):
    WHITE = '#FFFFFF'
    BLACK = '#000000'
    RED = '#FF000000'
    GREEN = '#00FF00'
    BLUE = '#0000FF'
    # TODO: Add colors from Manim or other libraries